@@ -70,6 +70,7 @@ struct _DictoWidgetPriv
 	GtkWidget *hbox;
 
 	/* Labels */
+	GtkWidget *pos_box;
 	GtkWidget *lbl_time;
 	GtkWidget *lbl_len;
 	GtkWidget *position;
@@ -246,7 +247,9 @@ priv->ndb=0;
 priv->vbox=gtk_vbox_new(FALSE, 2);
 v=gtk_vbox_new(FALSE, 2);
 h=gtk_hbox_new(FALSE, 2);
+
 priv->hbox=gtk_hbox_new(FALSE, 2);
+priv->pos_box=gtk_hbox_new(FALSE, 2);
 
 priv->lbl_time=gtk_label_new("");
 priv->lbl_len=gtk_label_new("");
@@ -304,23 +307,28 @@ gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(priv->level), GTK_PROGRESS_BOT
 
 gtk_box_pack_start(GTK_BOX(priv->vbox), priv->hbox, TRUE, TRUE, HILDON_MARGIN_DEFAULT);
 
-gtk_box_pack_start(GTK_BOX(h), priv->lbl_time, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
-gtk_box_pack_start(GTK_BOX(h), priv->position, TRUE, TRUE, HILDON_MARGIN_DEFAULT);
-gtk_box_pack_start(GTK_BOX(h), priv->lbl_len, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
+gtk_box_pack_start(GTK_BOX(priv->pos_box), priv->lbl_time, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
+gtk_box_pack_start(GTK_BOX(priv->pos_box), priv->position, TRUE, TRUE, HILDON_MARGIN_DEFAULT);
+gtk_box_pack_start(GTK_BOX(priv->pos_box), priv->lbl_len, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
 
-gtk_box_pack_start(GTK_BOX(priv->vbox), h, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
+gtk_box_pack_start(GTK_BOX(priv->vbox), priv->pos_box, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
 
 gtk_box_pack_start(GTK_BOX(v), priv->btn_record, FALSE, TRUE, 0);
 gtk_box_pack_start(GTK_BOX(v), priv->btn_play, FALSE, TRUE, 0);
 gtk_box_pack_start(GTK_BOX(v), priv->btn_stop, FALSE, TRUE, 0);
 gtk_box_pack_start(GTK_BOX(v), priv->btn_delete, FALSE, TRUE, 0);
 
+
 gtk_container_add(GTK_CONTAINER(priv->scroll), priv->file_tree);
 gtk_box_pack_start(GTK_BOX(priv->hbox), priv->scroll, TRUE, TRUE, HILDON_MARGIN_DEFAULT);
 gtk_box_pack_start(GTK_BOX(priv->hbox), priv->level, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
 gtk_box_pack_start(GTK_BOX(priv->hbox), v, FALSE, FALSE, HILDON_MARGIN_DEFAULT);
 
-gtk_widget_show(priv->vbox);
+gtk_widget_show_all(GTK_WIDGET(priv->vbox));
+
+gtk_widget_set_no_show_all(priv->level, TRUE);
+gtk_widget_set_no_show_all(priv->pos_box, TRUE);
+
 gtk_box_pack_start(GTK_BOX(dw), priv->vbox, TRUE, TRUE, 0);
 
 g_signal_connect(G_OBJECT(priv->btn_play), "toggled", G_CALLBACK(dicto_widget_play_cb), dw);
@@ -694,10 +702,12 @@ g_return_if_fail(priv);
 if (priv->dicto)
 	mode=dicto_get_state(priv->dicto);
 
-g_debug("Mode: %d", mode);
+g_debug("VMode: %d", mode);
 
 switch (mode) {
 	case DICTO_STATE_UNKNOWN:
+		/* This should never happen */
+		g_assert_not_reached();
 	case DICTO_STATE_ERROR:
 		/* XXX: What should we do ?*/
 	case DICTO_STATE_STOPPED:
@@ -713,6 +723,9 @@ switch (mode) {
 		gtk_widget_set_sensitive(priv->file_tree, TRUE);
 		gtk_widget_set_sensitive(priv->position, FALSE);
 
+		gtk_widget_hide(GTK_WIDGET(priv->level));
+		gtk_widget_hide(GTK_WIDGET(priv->pos_box));
+
 		selection=gtk_tree_view_get_selection(GTK_TREE_VIEW(priv->file_tree));
 		gtk_tree_selection_unselect_all(selection);
 		gtk_range_set_value(GTK_RANGE(priv->position), 0.0);
@@ -732,6 +745,7 @@ switch (mode) {
 	case DICTO_STATE_READY:
 		dicto_widget_position_set(priv, 0, 0);
 		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(priv->level), 0.0);
+
 		gtk_widget_set_sensitive(priv->btn_record, TRUE);
 		gtk_widget_set_sensitive(priv->btn_play, TRUE);
 		gtk_widget_set_sensitive(priv->btn_stop, FALSE);
@@ -739,14 +753,20 @@ switch (mode) {
 
 		gtk_widget_set_sensitive(priv->position, TRUE);
 		gtk_widget_set_sensitive(priv->file_tree, TRUE);
+
+		gtk_widget_show(GTK_WIDGET(priv->pos_box));
+		gtk_widget_show(GTK_WIDGET(priv->level));
+
 		gtk_range_set_value(GTK_RANGE(priv->position), 0.0);
 		gtk_range_set_update_policy(GTK_RANGE(priv->position), GTK_UPDATE_CONTINUOUS);
 	break;
 	case DICTO_STATE_RECORDING:
 		dicto_widget_position_clear(priv);
-		gtk_range_set_range(GTK_RANGE(priv->position), 0.0, 0.1);		
+		gtk_range_set_range(GTK_RANGE(priv->position), 0.0, 0.1);
 		dicto_widget_position_set(priv, 0, 0);
 	case DICTO_STATE_PLAYING:
+		gtk_widget_show(GTK_WIDGET(priv->pos_box));
+		gtk_widget_show(GTK_WIDGET(priv->level));
 #ifndef WITH_HILDON_2_2
 		gtk_range_set_update_policy(GTK_RANGE(priv->position), GTK_UPDATE_DELAYED);
 #endif
