@@ -47,6 +47,10 @@
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 
+#ifdef WITH_GIO
+#include <gio/gio.h>
+#endif
+
 #include "dicto.h"
 #include "dicto-ui-marshal.h"
 
@@ -137,6 +141,10 @@ struct _DictoPrivate {
 	gboolean has_decodebin;
 	GHashTable *notes;
 	GHashTable *tags;
+#if WITH_GIO
+	GFile *gf_bd;
+	GFileMonitor *gf_bd_m;
+#endif
 	dicto_pipeline play;
 	dicto_pipeline record;
 };
@@ -150,6 +158,7 @@ static guint signals[LAST_SIGNAL]={ 0 };
 static gboolean dicto_create_play_pipeline(Dicto *d, GError **error);
 static gboolean dicto_create_record_pipeline(Dicto *d, DictoFormats nf, GError **error);
 static gboolean dicto_notes_load_list(Dicto *d, gboolean s);
+static gboolean dicto_refresh_idle_cb(gpointer data);
 
 static void
 dicto_dispose(GObject *object)
@@ -307,7 +316,7 @@ dicto_notes_load_list(d, FALSE);
 return object;
 }
 
-static void 
+static void
 dicto_init(Dicto *d)
 {
 guint i=0;
@@ -316,7 +325,7 @@ DictoPrivate *p=GET_PRIVATE(d);
 
 p->formats=g_hash_table_new(g_direct_hash, g_direct_equal);
 while (dicto_formats[i].channels>0) {
-	f=&dicto_formats[i];
+	f=(DictoFormat *)&dicto_formats[i];
 	dicto_recording_format_add(d, f->id, f);
 	i++;
 }
@@ -324,6 +333,7 @@ p->rms=0.0;
 p->timefmt=g_strdup(DEF_TIME_FORMAT);
 p->pos_int=POS_INT_DEFAULT;
 p->tags=NULL;
+p->state=DICTO_STATE_STOPPED;
 }
 
 static void
@@ -539,6 +549,25 @@ DictoPrivate *p=GET_PRIVATE(d);
 return g_hash_table_remove(p->formats, GINT_TO_POINTER(f_id));
 }
 
+#ifdef WITH_GIO
+static void
+dicto_basedir_monitor_cb(GFileMonitor *monitor, GFile *file, GFile *other_file, GFileMonitorEvent event_type, gpointer data) 
+{
+switch (event_type) {
+	case G_FILE_MONITOR_EVENT_DELETED:
+		g_debug("GFME: Deleted");
+		g_idle_add(dicto_refresh_idle_cb, data);
+	break;
+	case G_FILE_MONITOR_EVENT_CREATED:
+		g_debug("GFME: Created");
+		g_idle_add(dicto_refresh_idle_cb, data);
+	break;
+	default:
+		g_debug("GFME: %d", event_type);
+}
+}
+#endif
+
 /**
  * dicto_set_basedir:
  * @d: A #Dicto object.
@@ -553,6 +582,7 @@ dicto_set_basedir(Dicto *d, const gchar *basedir)
 {
 gchar *tmp;
 DictoPrivate *p=GET_PRIVATE(d);
+GError *err=NULL;
 
 g_return_val_if_fail(d, FALSE);
 g_return_val_if_fail(basedir, FALSE);
@@ -570,11 +600,20 @@ if (g_mkdir_with_parents(tmp, 0775)==-1) {
 	return FALSE;
 }
 
-if (p->basedir)
+if (p->basedir) {
 	g_free(p->basedir);
+#ifdef WITH_GIO
+	g_object_unref(p->gf_bd_m);
+	g_object_unref(p->gf_bd);
+#endif
+}
 p->basedir=tmp;
 
-g_debug("Basedir: %s", p->basedir);
+#ifdef WITH_GIO
+p->gf_bd=g_file_new_for_path(p->basedir);
+p->gf_bd_m=g_file_monitor_directory(p->gf_bd, G_FILE_MONITOR_NONE, NULL, &err);
+g_signal_connect(p->gf_bd_m, "changed", G_CALLBACK(dicto_basedir_monitor_cb), d);
+#endif
 
 return TRUE;
 }
@@ -674,6 +713,14 @@ p->rms=*rms_dB/channels;
 return TRUE;
 }
 
+static gboolean
+dicto_pipeline_pause(DictoPrivate *p, dicto_pipeline *np)
+{
+if (gst_element_set_state(np->pipeline, GST_STATE_PAUSED)==GST_STATE_CHANGE_FAILURE)
+	return FALSE;
+return TRUE;
+}
+
 static void
 dicto_pipeline_stop(DictoPrivate *p, dicto_pipeline *np)
 {
@@ -859,7 +906,7 @@ if (p->record.active==TRUE) {
 	return FALSE;
 }
 
-f=&dicto_formats[nf];
+f=(DictoFormat *)&dicto_formats[nf];
 g_return_val_if_fail(f->id==nf, FALSE);
 
 encoder=NULL;
@@ -1288,6 +1335,12 @@ g_return_val_if_fail(d, FALSE);
 return dicto_notes_load_list(d, TRUE);
 }
 
+/**
+ * dicto_refresh_idle_cb:
+ *
+ * Idle handler helper for file list reloader.
+ *
+ */
 static gboolean
 dicto_refresh_idle_cb(gpointer data)
 {
@@ -1380,7 +1433,7 @@ if (p->tags)
 	g_hash_table_destroy(p->tags);
 p->tags=g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
-p->play.position=-0.0;
+p->play.position=0.0;
 p->play.length=0.0;
 
 gst_element_set_state(p->play.pipeline, GST_STATE_NULL);
@@ -1394,6 +1447,7 @@ if (gst_element_set_state(p->play.pipeline, GST_STATE_PAUSED)==GST_STATE_CHANGE_
 if (gst_element_get_state(p->play.pipeline, &current, NULL, GST_SECOND/2)==GST_STATE_CHANGE_FAILURE) {
 	g_warning("Async state change failed");
 	gst_element_set_state(p->play.pipeline, GST_STATE_NULL);
+	dicto_position_cb(d);
 	return FALSE;
 }
 
@@ -1509,7 +1563,9 @@ p->record.active=TRUE;
 dicto_position_update(d, TRUE);
 p->state=DICTO_STATE_RECORDING;
 g_signal_emit(d, signals[SIGNAL_RECORDING], 0, NULL);
+#ifndef WITH_GIO
 g_idle_add(dicto_refresh_idle_cb, d);
+#endif
 
 return TRUE;
 }
@@ -1577,7 +1633,6 @@ g_free(tmp);
 if (g_hash_table_remove(p->notes, file)==FALSE) {
 	g_warning("Failed to remove file from cache, reloading list");
 	dicto_notes_load_list(d, TRUE);
-	return TRUE;
 }
 
 /* Make sure we can change the location */
@@ -1639,6 +1694,28 @@ if (p->play.pipeline && p->play.active) {
 return FALSE;
 }
 
+/**
+ * dicto_pause:
+ * @d: A #Dicto object
+ *
+ * Pauses the recording.
+ *
+ */
+gboolean
+dicto_pause_record(Dicto *d)
+{
+DictoPrivate *p=GET_PRIVATE(d);
+
+switch (p->state) {
+	case DICTO_STATE_RECORDING:
+		return dicto_pipeline_pause(p, &p->record);
+	default:
+		return FALSE;
+}
+
+return FALSE;
+}
+
 /**
  * dicto_stop:
  * @d: A #Dicto object
@@ -1770,25 +1847,27 @@ dicto_get_position(Dicto *d, gdouble *length, gdouble *position)
 {
 DictoPrivate *p=GET_PRIVATE(d);
 GstFormat fmt=GST_FORMAT_TIME;
-GstElement *pipe;
+GstState current, pending;
 dicto_pipeline *dp;
 gint64 pos, len;
-gboolean r;
-GstState current, pending;
+gboolean r=TRUE;
 
 g_return_val_if_fail(d, FALSE);
 
 dp=(p->record.active) ? &p->record : &p->play;
-pipe=dp->pipeline;
-g_return_val_if_fail(pipe, FALSE);
+g_return_val_if_fail(dp, FALSE);
+g_return_val_if_fail(dp->pipeline, FALSE);
 
-r=gst_element_query_duration(pipe, &fmt, &len);
-dp->length=GST_TIME_TO_SECS(len);
+/* Query length only if we don't know it yet (=0) or if we are recording */
+if (dp->length==0 || p->record.active) {
+	r=gst_element_query_duration(dp->pipeline, &fmt, &len);
+	dp->length=GST_TIME_TO_SECS(len);
+}
 
 if (length)
 	*length=dp->length;
 
-if (gst_element_get_state(pipe, &current, &pending, GST_SECOND)==GST_STATE_CHANGE_FAILURE)
+if (gst_element_get_state(dp->pipeline, &current, &pending, GST_SECOND)==GST_STATE_CHANGE_FAILURE)
 	return FALSE;
 
 switch (current) {
@@ -1797,7 +1876,7 @@ switch (current) {
 	break;
 	case GST_STATE_READY:
 	case GST_STATE_PLAYING:
-		r=gst_element_query_position(pipe, &fmt, &pos);
+		r=gst_element_query_position(dp->pipeline, &fmt, &pos);
 		dp->position=GST_TIME_TO_SECS(pos);
 	break;
 	case GST_STATE_NULL:
